<?php
/** Chinese (Singapore) (‪中文(新加坡)‬)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author PhiLiP
 * @author Shizhao
 * @author Wong128hk
 */

# Inherit everything for now
$fallback = 'zh-hans';

$messages = array(
# User preference toggles
'tog-norollbackdiff' => '进行回退后略过差异比较',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'portal' => '社区入口',

# Edit pages
'editing' => '正在编辑 $1',

);
